Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1982)

Unified Diff: content/public/browser/content_browser_client.h

Issue 2379703002: [Presentation API] (alternative) 1-UA: send message between controller and receiver page (Closed)
Patch Set: merge with master Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/browser/content_browser_client.h
diff --git a/content/public/browser/content_browser_client.h b/content/public/browser/content_browser_client.h
index 3aa2a4911fc341c8d7a1419ae4bf1baa40d28227..bceedf7315132651425f69aa7df0b8ceabf639ff 100644
--- a/content/public/browser/content_browser_client.h
+++ b/content/public/browser/content_browser_client.h
@@ -109,6 +109,7 @@ class BrowserPluginGuestDelegate;
class BrowserPpapiHost;
class BrowserURLHandler;
class ClientCertificateDelegate;
+class ControllerPresentationServiceDelegate;
class DevToolsManagerDelegate;
class ExternalVideoSurfaceContainer;
class GpuProcessHost;
@@ -118,8 +119,8 @@ class MemoryCoordinatorDelegate;
class NavigationHandle;
class NavigationUIData;
class PlatformNotificationService;
-class PresentationServiceDelegate;
class QuotaPermissionContext;
+class ReceiverPresentationServiceDelegate;
class RenderFrameHost;
class RenderProcessHost;
class RenderViewHost;
@@ -708,10 +709,15 @@ class CONTENT_EXPORT ContentBrowserClient {
RenderFrameHost* render_frame_host,
blink::WebPageVisibilityState* visibility_state) {}
// Allows an embedder to provide its own PresentationServiceDelegate
// implementation. Returns nullptr if unavailable.
- virtual PresentationServiceDelegate* GetPresentationServiceDelegate(
- WebContents* web_contents);
+ virtual ControllerPresentationServiceDelegate*
+ GetControllerPresentationServiceDelegate(WebContents* web_contents);
+
+ // Allows an embedder to provide its own ReceiverPresentationServiceDelegate
+ // implementation. Returns nullptr if unavailable.
+ virtual ReceiverPresentationServiceDelegate*
+ GetReceiverPresentationServiceDelegate(WebContents* web_contents);
// Allows programmatic opening of a new tab/window without going through
// another WebContents. For example, from a Worker. |callback| will be
« no previous file with comments | « content/browser/presentation/presentation_type_converters.h ('k') | content/public/browser/content_browser_client.cc » ('j') | no next file with comments »
@@ -708,10 +709,15 @@ class CONTENT_EXPORT ContentBrowserClient {
RenderFrameHost* render_frame_host,
blink::WebPageVisibilityState* visibility_state) {}
- // Allows an embedder to provide its own PresentationServiceDelegate
+ // Allows an embedder to provide its own ControllerPresentationServiceDelegate
// implementation. Returns nullptr if unavailable.

Powered by Google App Engine
This is Rietveld 408576698